# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkimageenhan.endpoint import endpoint_data

class RecolorHDImageRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imageenhan', '2019-09-30', 'RecolorHDImage','imageenhan')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Mode(self): # String
		return self.get_body_params().get('Mode')

	def set_Mode(self, Mode):  # String
		self.add_body_params('Mode', Mode)
	def get_ColorCount(self): # Integer
		return self.get_body_params().get('ColorCount')

	def set_ColorCount(self, ColorCount):  # Integer
		self.add_body_params('ColorCount', ColorCount)
	def get_ColorTemplates(self): # RepeatList
		return self.get_body_params().get('ColorTemplate')

	def set_ColorTemplates(self, ColorTemplate):  # RepeatList
		for depth1 in range(len(ColorTemplate)):
			if ColorTemplate[depth1].get('Color') is not None:
				self.add_body_params('ColorTemplate.' + str(depth1 + 1) + '.Color', ColorTemplate[depth1].get('Color'))
	def get_Degree(self): # String
		return self.get_body_params().get('Degree')

	def set_Degree(self, Degree):  # String
		self.add_body_params('Degree', Degree)
	def get_Url(self): # String
		return self.get_body_params().get('Url')

	def set_Url(self, Url):  # String
		self.add_body_params('Url', Url)
	def get_RefUrl(self): # String
		return self.get_body_params().get('RefUrl')

	def set_RefUrl(self, RefUrl):  # String
		self.add_body_params('RefUrl', RefUrl)
